@@ -1,10 +1,11 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-"Timesheet Line"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import FIELDS
-from trytond.pyson import Eval, PYSONEncoder, Date
+from trytond.pyson import Eval, PYSONEncoder, Date, Get
+from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 
 class Line(ModelSQL, ModelView):
@@ -13,7 +14,7 @@ class Line(ModelSQL, ModelView):
     _description = __doc__
 
     employee = fields.Many2One('company.employee', 'Employee', required=True,
-            select=1, domain=[('company', '=', Eval('company'))])
+        select=1, domain=[('company', '=', Get(Eval('context', {}), 'company'))])
     date = fields.Date('Date', required=True, select=1)
     hours = fields.Float('Hours', digits=(16, 2), required=True)
     work = fields.Many2One('timesheet.work', 'Work',
@@ -29,39 +30,31 @@ class Line(ModelSQL, ModelView):
              'CHECK(hours >= 0.0)', 'Hours field must be positive'),
             ]
 
-    def default_employee(self, cursor, user_id, context=None):
-        user_obj = self.pool.get('res.user')
-        employee_obj = self.pool.get('company.employee')
+    def default_employee(self):
+        user_obj = Pool().get('res.user')
+        employee_obj = Pool().get('company.employee')
 
-        if context is None:
-            context = {}
         employee_id = None
-        if context.get('employee'):
-            employee_id = context['employee']
+        if Transaction().context.get('employee'):
+            employee_id = Transaction().context['employee']
         else:
-            user = user_obj.browse(cursor, user_id, user_id, context=context)
+            user = user_obj.browse(Transaction().user)
             if user.employee:
                 employee_id = user.employee.id
         if employee_id:
             return employee_id
         return False
 
-    def default_date(self, cursor, user, context=None):
-        date_obj = self.pool.get('ir.date')
+    def default_date(self):
+        date_obj = Pool().get('ir.date')
 
-        if context is None:
-            context = {}
-        if context.get('date'):
-            return context['date']
-        return date_obj.today(cursor, user, context=context)
+        return Transaction().context.get('date') or date_obj.today()
 
-    def view_header_get(self, cursor, user, value, view_type='form',
-            context=None):
-        if not context.get('employee'):
+    def view_header_get(self, value, view_type='form'):
+        if not Transaction().context.get('employee'):
             return value
-        employee_obj = self.pool.get('company.employee')
-        employee = employee_obj.browse(cursor, user, context['employee'],
-                                       context=context)
+        employee_obj = Pool().get('company.employee')
+        employee = employee_obj.browse(Transaction().context['employee'])
         return value + " (" + employee.name + ")"
 
 Line()
@@ -72,16 +65,16 @@ class EnterLinesInit(ModelView):
     _name = 'timesheet.enter_lines.init'
     _description = __doc__
     employee = fields.Many2One('company.employee', 'Employee', required=True,
-            domain=[('company', '=', Eval('company'))])
+            domain=[('company', '=', Get(Eval('context', {}), 'company'))])
     date = fields.Date('Date', required=True)
 
-    def default_employee(self, cursor, user, context=None):
-        line_obj = self.pool.get('timesheet.line')
-        return line_obj.default_employee(cursor, user, context=context)
+    def default_employee(self):
+        line_obj = Pool().get('timesheet.line')
+        return line_obj.default_employee()
 
-    def default_date(self, cursor, user, context=None):
-        line_obj = self.pool.get('timesheet.line')
-        return line_obj.default_date(cursor, user, context=context)
+    def default_date(self):
+        line_obj = Pool().get('timesheet.line')
+        return line_obj.default_date()
 
 EnterLinesInit()
 
@@ -109,13 +102,13 @@ class EnterLines(Wizard):
         }
     }
 
-    def _action_enter_lines(self, cursor, user, data, context=None):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        employee_obj = self.pool.get('company.employee')
-        act_window_id = model_data_obj.get_id(cursor, user, 'timesheet',
-                'act_line_form', context=context)
-        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+    def _action_enter_lines(self, data):
+        pool = Pool()
+        model_data_obj = pool.get('ir.model.data')
+        act_window_obj = pool.get('ir.action.act_window')
+        employee_obj = pool.get('company.employee')
+        act_window_id = model_data_obj.get_id('timesheet', 'act_line_form')
+        res = act_window_obj.read(act_window_id)
         date = data['form']['date']
         date = Date(date.year, date.month, date.day)
         res['pyson_domain'] = PYSONEncoder().encode([
@@ -128,8 +121,7 @@ class EnterLines(Wizard):
             })
 
         if data['form']['employee']:
-            employee = employee_obj.browse(
-                cursor, user, data['form']['employee'], context=context)
+            employee = employee_obj.browse(data['form']['employee'])
             res['name'] += " - " + employee.rec_name
 
         return res
@@ -145,17 +137,15 @@ class HoursEmployee(ModelSQL, ModelView):
     employee = fields.Many2One('company.employee', 'Employee', select=1)
     hours = fields.Float('Hours', digits=(16, 2))
 
-    def table_query(self, context=None):
-        if context is None:
-            context = {}
+    def table_query(self):
         clause = ' '
-        args = []
-        if context.get('start_date'):
+        args = [True]
+        if Transaction().context.get('start_date'):
             clause += 'AND date >= %s '
-            args.append(context['start_date'])
-        if context.get('end_date'):
+            args.append(Transaction().context['start_date'])
+        if Transaction().context.get('end_date'):
             clause += 'AND date <= %s '
-            args.append(context['end_date'])
+            args.append(Transaction().context['end_date'])
         return ('SELECT DISTINCT(employee) AS id, ' \
                     'MAX(create_uid) AS create_uid, ' \
                     'MAX(create_date) AS create_date, ' \
@@ -164,7 +154,7 @@ class HoursEmployee(ModelSQL, ModelView):
                     'employee, ' \
                     'SUM(COALESCE(hours, 0)) AS hours ' \
                 'FROM timesheet_line ' \
-                'WHERE True ' \
+                'WHERE %s ' \
                 + clause + \
                 'GROUP BY employee', args)
 
@@ -204,12 +194,12 @@ class OpenHoursEmployee(Wizard):
         },
     }
 
-    def _action_open(self, cursor, user, data, context=None):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        act_window_id = model_data_obj.get_id(cursor, user, 'timesheet',
-                'act_hours_employee_form', context=context)
-        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+    def _action_open(self, data):
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
+        act_window_id = model_data_obj.get_id('timesheet',
+            'act_hours_employee_form')
+        res = act_window_obj.read(act_window_id)
         res['pyson_context'] = PYSONEncoder().encode({
             'start_date': data['form']['start_date'],
             'end_date': data['form']['end_date'],
@@ -235,10 +225,11 @@ class HoursEmployeeWeekly(ModelSQL, ModelView):
         self._order.insert(1, ('week', 'DESC'))
         self._order.insert(2, ('employee', 'ASC'))
 
-    def table_query(self, context=None):
+    def table_query(self):
         type_name = FIELDS[self.year._type].sql_type(self.year)[0]
         return ('SELECT id, create_uid, create_date, write_uid, write_date, ' \
-                    'CAST(year AS ' + type_name + '), week, employee, hours ' \
+                    'CAST(year AS ' + type_name + ') AS year, week, ' \
+                    'employee, hours ' \
                     'FROM ('
                         'SELECT EXTRACT(WEEK FROM date) + ' \
                             'EXTRACT(YEAR FROM date) * 100 + ' \
@@ -272,10 +263,11 @@ class HoursEmployeeMonthly(ModelSQL, ModelView):
         self._order.insert(1, ('month', 'DESC'))
         self._order.insert(2, ('employee', 'ASC'))
 
-    def table_query(self, context=None):
+    def table_query(self):
         type_name = FIELDS[self.year._type].sql_type(self.year)[0]
         return ('SELECT id, create_uid, create_date, write_uid, write_date, ' \
-                    'CAST(year AS ' + type_name + '), month, employee, hours ' \
+                    'CAST(year AS ' + type_name + ') AS year, month, ' \
+                    'employee, hours ' \
                     'FROM ('
                         'SELECT EXTRACT(MONTH FROM date) + ' \
                             'EXTRACT(YEAR FROM date) * 100 + ' \
