@@ -2,8 +2,10 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
-from trytond.pyson import PYSONEncoder
+from trytond.pyson import PYSONEncoder, Not, Bool, Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
+
 
 class Work(ModelSQL, ModelView):
     'Work'
@@ -22,6 +24,13 @@ class Work(ModelSQL, ModelView):
     timesheet_available = fields.Boolean('Available on timesheets',
             help="Allow to fill in timesheets with this work")
     company = fields.Many2One('company.company', 'Company', required=True)
+    timesheet_lines = fields.One2Many('timesheet.line', 'work',
+        'Timesheet Lines',
+        depends=['timesheet_available', 'active'],
+        states={
+            'invisible': Not(Bool(Eval('timesheet_available'))),
+            'readonly': Not(Bool(Eval('active'))),
+            })
 
     def __init__(self):
         super(Work, self).__init__()
@@ -111,6 +120,14 @@ class Work(ModelSQL, ModelView):
             res[work.id] = _name(work)
         return res
 
+    def copy(self, ids, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        if 'timesheet_lines' not in default:
+            default['timesheet_lines'] = False
+        return super(Work, self).copy(ids, default=default)
+
     def write(self, ids, vals):
         child_ids = None
         if not vals.get('active', True):
@@ -160,9 +177,9 @@ class OpenWork(Wizard):
     }
 
     def _action_open_work(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        act_window_id = model_data_obj.get_id('timesheet', 'act_work_tree2')
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
+        act_window_id = model_data_obj.get_id('timesheet', 'act_work_hours_board')
         res = act_window_obj.read(act_window_id)
         res['pyson_context'] = PYSONEncoder().encode({
             'from_date': data['form']['from_date'],
@@ -177,8 +194,8 @@ class OpenWork2(OpenWork):
     _name = 'timesheet.work.open2'
 
     def _action_open_work(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
         act_window_id = model_data_obj.get_id('timesheet', 'act_work_form2')
         res = act_window_obj.read(act_window_id)
         res['pyson_context'] = PYSONEncoder().encode({
@@ -203,9 +220,10 @@ class OpenWorkGraph(Wizard):
     }
 
     def _action_open_work(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
-        work_obj = self.pool.get('timesheet.work')
+        pool = Pool()
+        model_data_obj = pool.get('ir.model.data')
+        act_window_obj = pool.get('ir.action.act_window')
+        work_obj = pool.get('timesheet.work')
 
         act_window_id = model_data_obj.get_id('timesheet', 'act_work_form3')
         res = act_window_obj.read(act_window_id)
